@@ -4,9 +4,9 @@
 
 #pragma once
 
-#include "csapi/definitions/wellknown/full.h"
+#include <Quotient/csapi/definitions/wellknown/full.h>
 
-#include "jobs/basejob.h"
+#include <Quotient/jobs/basejob.h>
 
 namespace Quotient {
 
@@ -21,7 +21,7 @@ namespace Quotient {
  * Note that this endpoint is not necessarily handled by the homeserver,
  * but by another webserver, to be used for discovering the homeserver URL.
  */
-class GetWellknownJob : public BaseJob {
+class QUOTIENT_API GetWellknownJob : public BaseJob {
 public:
     /// Gets Matrix server discovery information about the domain.
     explicit GetWellknownJob();
